@@ -1,5 +1,5 @@
-# Copyright (c) 2004-2005 Timothy Appnel
-# http://www.timaoutloud.org/
+# Copyright (c) 2004-2009 Timothy Appnel
+# http://appnel.com/
 # This code is released under the Artistic License.
 #
 # XML::RAI - RSS Abstraction Interface.
@@ -10,7 +10,7 @@ package XML::RAI;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = 1.3022;
+$VERSION = 1.303;
 
 use XML::RSS::Parser 4.0;
 use XML::RAI::Channel;
@@ -39,7 +39,8 @@ sub init {
         my ($method, @r) = @_;
         $parser ||= XML::RSS::Parser->new;
         $doc = $parser->$method(@r) or die $parser->errstr;
-    } else {
+    }
+    else {
         $doc = shift;
     }
     $self->{__doc} = $doc;
@@ -48,7 +49,8 @@ sub init {
     my @items = map { XML::RAI::Item->new($_, $channel) } $doc->items;
     $self->{__items} = \@items;
     my @imgs = $doc->image;    # fix multiple image bug ala slashdot.
-    $self->{__image} = XML::RAI::Image->new($imgs[0], $channel) if $doc->image;
+    $self->{__image} = XML::RAI::Image->new($imgs[0], $channel)
+      if $doc->image;
     $self->{__timef} = W3CDTF;
 }
 
@@ -61,7 +63,8 @@ sub parse {
     my $class = shift;
     if (ref($_[0]) eq 'GLOB') {    # is filehandle
         $class->parse_file(@_);
-    } else {                       # is string
+    }
+    else {                         # is string
         $class->parse_string(@_);
     }
 }
@@ -298,7 +301,7 @@ L<http://www.perl.com/language/misc/Artistic.html>.
 =head1 AUTHOR & COPYRIGHT
 
 Except where otherwise noted, XML::RAI is Copyright
-2003-2005, Timothy Appnel, cpan@timaoutloud.org. All rights
+2003-2009, Timothy Appnel, tima@cpan.org. All rights
 reserved.
 
 =cut
